Kaleidoscope
--------------

Implementing a Language with LLVM

The LLVM `Kaleidoscope <http://www.llvm.org/docs/tutorial/>`_ tutorial
has been ported to llvmpy by Max Shawabkeh.

.. toctree::
   :titlesonly:
   :numbered:

   PythonLangImpl1.rst
   PythonLangImpl2.rst
   PythonLangImpl3.rst
   PythonLangImpl4.rst
   PythonLangImpl5.rst
   PythonLangImpl6.rst
   PythonLangImpl7.rst
   PythonLangImpl8.rst

